### Table A3: Sensor Data Summary
| Sensor | Location | Mean | Min | Max | Duration |
|--------|----------|------|-----|-----|----------|
| CO₂-01 | Chamber | 1240 | 620 | 2100 | 21 days |
| CO₂-02 | Approach | 890 | 580 | 1450 | 21 days |
| T-01 | Chamber | 14.2 | 13.0 | 15.2 | 21 days |
| T-02 | Approach | 13.5 | 12.8 | 14.5 | 21 days |
| WL-01 | Stream | 0.45 | 0.22 | 0.85 | 21 days |

---

## 15. Conclusions

The Frasassi 2022 expedition successfully documented a rare CDZ event in real-time, providing unprecedented data on chamber formation dynamics. Key achievements include:

1. **First real-time documentation** of a major CDZ event
2. **Validation** of CAVORA predictive capabilities
3. **Quantification** of dissolution rates during active phase
4. **Demonstration** of effective safety protocols
5. **Discovery** of 150m of new passage
6. **Publication** of 3 peer-reviewed papers
7. **Training** of 12 researchers in CDZ protocols

The event demonstrated that CDZs can be predicted with sufficient lead time for safe operation, and that proper protocols enable scientific documentation of otherwise hazardous phenomena.

---

**Report Date**: July 15, 2022  
**Authors**: S. Baladi, A. Rossi, F. Bianchi  
**Status**: Final  

*For more information: frasassi@cavora.org*

---

*"We witnessed the cave being born in real-time - a privilege few speleologists ever experience."*  
— Alessandro Rossi, Expedition Leader
### Table A3: Sensor Data Summary
| Sensor | Location | Mean | Min | Max | Duration |
|--------|----------|------|-----|-----|----------|
| CO₂-01 | Chamber | 1240 | 620 | 2100 | 21 days |
| CO₂-02 | Approach | 890 | 580 | 1450 | 21 days |
| T-01 | Chamber | 14.2 | 13.0 | 15.2 | 21 days |
| T-02 | Approach | 13.5 | 12.8 | 14.5 | 21 days |
| WL-01 | Stream | 0.45 | 0.22 | 0.85 | 21 days |

---

## 15. Conclusions

The Frasassi 2022 expedition successfully documented a rare CDZ event in real-time, providing unprecedented data on chamber formation dynamics. Key achievements include:

1. **First real-time documentation** of a major CDZ event
2. **Validation** of CAVORA predictive capabilities
3. **Quantification** of dissolution rates during active phase
4. **Demonstration** of effective safety protocols
5. **Discovery** of 150m of new passage
6. **Publication** of 3 peer-reviewed papers
7. **Training** of 12 researchers in CDZ protocols

The event demonstrated that CDZs can be predicted with sufficient lead time for safe operation, and that proper protocols enable scientific documentation of otherwise hazardous phenomena.

---

**Report Date**: July 15, 2022  
**Authors**: S. Baladi, A. Rossi, F. Bianchi  
**Status**: Final  

*For more information: frasassi@cavora.org*

---

*"We witnessed the cave being born in real-time - a privilege few speleologists ever experience."*  
— Alessandro Rossi, Expedition Leader
